abacusai.function_logs — AbacusAI documentation

# `abacusai.function_logs`

## Module Contents

### Classes

`FunctionLogs` | Logs from an invocation of a function.

class abacusai.function_logs.FunctionLogs(client, function=None, stats=None, stdout=None, stderr=None, exception={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs from an invocation of a function.

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - function (str) –

    - stats (dict) –

    - stdout (str) –

    - stderr (str) –

    - exception (UserException) –

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict